from .Leaf import Leaf
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class LeafFromGeometry(Leaf):
    """The LeafFromGeometry object can be used whenever a Leaf object is expected as an
    argument. Leaf objects are used to specify the items in a display group. Leaf objects
    are constructed as temporary objects, which are then used as arguments to DisplayGroup
    commands.
    The LeafFromGeometry object is derived from the Leaf object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import displayGroupMdbToolset
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
    #: DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.
    leafType: SymbolicConstant = None

    @abaqus_method_doc
    def __init__(self, edgeSeq: tuple = (), faceSeq: tuple = (), cellSeq: tuple = ()):
        """This method creates a Leaf object from a sequence of edge, face and cell geometry
        objects. Any combination of edge, face or cell arguments is allowed however the
        arguments must specify at least one object--it is not permissible to create an empty
        leaf.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                LeafFromGeometry

        Parameters
        ----------
        edgeSeq
            A sequence of geometry edges.
        faceSeq
            A sequence of geometry faces.
        cellSeq
            A sequence of geometry cells.

        Returns
        -------
        LeafFromGeometry
            A :py:class:`~abaqus.DisplayGroup.LeafFromGeometry.LeafFromGeometry` object.

        Raises
        ------
        Cannot define empty leaf
            If at least one of the sequences is not passed to this method.
        """
        super().__init__(DEFAULT_MODEL)



from .BoundaryConditionState import BoundaryConditionState
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc


@abaqus_class_doc
class SecondaryBaseBCState(BoundaryConditionState):
    """The SecondaryBaseBCState object stores the propagating data for a slave base
    boundary condition in a step. One instance of this object is created internally by the
    SecondaryBaseBC object for each step. The instance is also deleted internally by the
    SecondaryBaseBC object.
    The SecondaryBaseBCState object has no constructor or methods.
    The SecondaryBaseBCState object is derived from the BoundaryConditionState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].steps[name].boundaryConditionStates[name]

        The corresponding analysis keywords are:

        - BOUNDARY
    """

    #: A SymbolicConstant specifying the propagation state of the amplitude reference. Possible
    #: values are UNSET, SET, UNCHANGED, FREED, and MODIFIED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the BoundaryConditionState object. Possible values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - PROPAGATED_FROM_BASE_STATE
    #: - MODIFIED_FROM_BASE_STATE
    #: - DEACTIVATED_FROM_BASE_STATE
    #: - BUILT_INTO_MODES
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the
    #: boundary condition has no amplitude reference.
    amplitude: str = ""



import typing

from .Leaf import Leaf
from ..Region.Set import Set
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class LeafFromSets(Leaf):
    """The LeafFromSets object can be used whenever a Leaf object is expected as an argument.
    Leaf objects are used to specify the items in a display group. Leaf objects are
    constructed as temporary objects, which are then used as arguments to DisplayGroup
    commands.
    The LeafFromSets object is derived from the Leaf object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import displayGroupMdbToolset
    """

    #: A SymbolicConstant specifying the leaf type. Possible values are EMPTY_LEAF,
    #: DEFAULT_MODEL, ALL_ELEMENTS, ALL_NODES, and ALL_SURFACES.
    leafType: SymbolicConstant = None

    @abaqus_method_doc
    def __init__(self, sets: typing.Tuple[Set, ...]):
        """This method creates a Leaf object from a sequence of Set objects.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                LeafFromSets

        Parameters
        ----------
        sets
            A sequence of Set objects.

        Returns
        -------
        LeafFromSets
            A :py:class:`~abaqus.DisplayGroup.LeafFromSets.LeafFromSets` object.
        """
        super().__init__(DEFAULT_MODEL)



from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class Constraint:
    """The ConstrainedSketchConstraint object is the abstract base type for other ConstrainedSketchConstraint objects. The
    ConstrainedSketchConstraint object has no explicit constructor. The members of the ConstrainedSketchConstraint object are
    common to all objects derived from the ConstrainedSketchConstraint.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].constraints[name]
    """

    #: A String specifying the constraint repository key.
    name: str = ""

    #: A Boolean specifying whether the constraint is suppressed or not. The default value is
    #: OFF.
    suppressed: Boolean = OFF

    @abaqus_method_doc
    def resume(self):
        """This method resumes the constraint that was previously suppressed."""
        ...

    @abaqus_method_doc
    def suppress(self):
        """This method suppresses the constraint."""
        ...

    @abaqus_method_doc
    def delete(self, indices: tuple):
        """This method allows you to delete existing constraints.

        Parameters
        ----------
        indices
            A sequence of Ints specifying the index of each constraint to delete.
        """
        ...



import typing

from .ReferencePoint import ReferencePoint


class ReferencePoints(typing.Dict[int, ReferencePoint]):
    def __getitem__(self, key: int) -> ReferencePoint:
        if key in self.keys():
            return self.get(key)
        else:
            return ReferencePoint(point=(0.0, 0.0, 0.0))



from odbAccess import AnalyticSurfaceProfile
from abaqus.Odb.AnalyticSurfaceSegment import AnalyticSurfaceSegment
from abaqus.Odb.HistoryPoint import HistoryPoint
from abaqus.Job.Job import Job
from odbAccess import Odb
from odbAccess import isUpgradeRequiredForOdb
from odbAccess import openOdb
from odbAccess import upgradeOdb
# from odbAccess import closeOdb
# from odbAccess import truncateOdb



import typing

from .Load import Load
from ..Region.Region import Region
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class ConnectorForce(Load):
    """The ConnectorForce object defines a connector force.
    The ConnectorForce object is derived from the Load object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].loads[name]
    """

    #: A String specifying the load repository key.
    name: str = ""

    #: A String specifying the name of the assembled fastener to which the load will be
    #: applied. This argument is not valid when **region** is specified. When this argument is
    #: specified, **fastenerSetName** must also be specified. The default value is an empty
    #: string.
    fastenerName: str = ""

    #: A String specifying the assembled fastener template model set to which the load will be
    #: applied. This argument is not valid when **region** is specified. When this argument is
    #: specified, **fastenerName** must also be specified. The default value is an empty string.
    fastenerSetName: str = ""

    #: A :py:class:`~abaqus.Region.Region.Region` object specifying the region to which the load is applied.
    region: Region = Region()

    @abaqus_method_doc
    def __init__(
        self,
        name: str,
        createStepName: str,
        region: str = "",
        fastenerName: str = "",
        fastenerSetName: str = "",
        f1: float = None,
        f2: float = None,
        f3: float = None,
        amplitude: str = UNSET,
    ):
        """This method creates a ConnectorForce object on a wire region. Alternatively, the load
        may also be applied to a wire set referenced from an assembled fastener template model.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].ConnectorForce

        Parameters
        ----------
        name
            A String specifying the load repository key.
        createStepName
            A String specifying the name of the step in which the load is created.
        region
            The wire region to which the load is applied. This argument is not valid when
            **fastenerName** and **fastenerSetName** are specified.
        fastenerName
            A String specifying the name of the assembled fastener to which the load will be
            applied. This argument is not valid when **region** is specified. When this argument is
            specified, **fastenerSetName** must also be specified. The default value is an empty
            string.
        fastenerSetName
            A String specifying the assembled fastener template model set to which the load will be
            applied. This argument is not valid when **region** is specified. When this argument is
            specified, **fastenerName** must also be specified. The default value is an empty string.
        f1
            A Float or a Complex specifying the connector force component in the connector's local
            1-direction.Note:Although **f1**, **f2**, and **f3** are optional arguments, at least one of
            them must be nonzero.
        f2
            A Float or a Complex specifying the connector force component in the connector's local
            2-direction.
        f3
            A Float or a Complex specifying the connector force component in the connector's local
            3-direction.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.

        Returns
        -------
        ConnectorForce
            A :py:class:`~abaqus.Load.ConnectorForce.ConnectorForce` object.
        """
        super().__init__()

    @abaqus_method_doc
    def setValues(
        self,
        region: str = "",
        fastenerName: str = "",
        fastenerSetName: str = "",
        f1: float = None,
        f2: float = None,
        f3: float = None,
        amplitude: str = UNSET,
    ):
        """This method modifies the data for an existing ConnectorForce object in the step where it
        is created.

        Parameters
        ----------
        region
            The wire region to which the load is applied. This argument is not valid when
            **fastenerName** and **fastenerSetName** are specified.
        fastenerName
            A String specifying the name of the assembled fastener to which the load will be
            applied. This argument is not valid when **region** is specified. When this argument is
            specified, **fastenerSetName** must also be specified. The default value is an empty
            string.
        fastenerSetName
            A String specifying the assembled fastener template model set to which the load will be
            applied. This argument is not valid when **region** is specified. When this argument is
            specified, **fastenerName** must also be specified. The default value is an empty string.
        f1
            A Float or a Complex specifying the connector force component in the connector's local
            1-direction.Note:Although **f1**, **f2**, and **f3** are optional arguments, at least one of
            them must be nonzero.
        f2
            A Float or a Complex specifying the connector force component in the connector's local
            2-direction.
        f3
            A Float or a Complex specifying the connector force component in the connector's local
            3-direction.
        amplitude
            A String or the SymbolicConstant UNSET specifying the name of the amplitude reference.
            UNSET should be used if the load has no amplitude reference. The default value is UNSET.
            You should provide the **amplitude** argument only if it is valid for the specified step.
        """
        ...

    @abaqus_method_doc
    def setValuesInStep(
        self,
        stepName: str,
        f1: typing.Union[SymbolicConstant, float] = None,
        f2: typing.Union[SymbolicConstant, float] = None,
        f3: typing.Union[SymbolicConstant, float] = None,
        amplitude: str = "",
    ):
        """This method modifies the propagating data for an existing ConnectorForce object in the
        specified step.

        Parameters
        ----------
        stepName
            A String specifying the name of the step in which the load is modified.
        f1
            A Float, a Complex, or the SymbolicConstant UNCHANGED specifying the connector force
            component in the connector's local 1-direction. UNCHANGED should be used if the
            connector force component is propagated from the previous analysis step.
        f2
            A Float, a Complex, or the SymbolicConstant UNCHANGED specifying the connector force
            component in the connector's local 2-direction. UNCHANGED should be used if the
            connector force component is propagated from the previous analysis step.
        f3
            A Float, a Complex, or the SymbolicConstant UNCHANGED specifying the connector force
            component in the connector's local 3-direction. UNCHANGED should be used if the
            connector force component is propagated from the previous analysis step.
        amplitude
            A String or a SymbolicConstant specifying the name of the amplitude reference. Possible
            values for the SymbolicConstant are UNCHANGED and FREED. UNCHANGED should be used if the
            amplitude is propagated from the previous analysis step. FREED should be used if the
            load is changed to have no amplitude reference. You should provide the **amplitude**
            argument only if it is valid for the specified step.
        """
        ...



from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc, abaqus_method_doc


@abaqus_class_doc
class GeometricProperties:
    """The GeometricProperties object specifies surface interaction properties.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import interaction
            mdb.models[name].interactionProperties[name].geometricProperties

        The corresponding analysis keywords are:

        - SURFACE INTERACTION
    """

    #: A Float specifying the out-of-plane thickness of the surface for a two-dimensional model
    #: or cross-sectional area for every node in the node-based surface. The default value is
    #: 1.0.
    contactArea: float = 1

    #: None or a Float specifying the thickness of an interfacial layer between the contacting
    #: surfaces. If **padThickness** = None, there is no interfacial layer. The default value is
    #: None.
    padThickness: float = None

    #: None or a Float specifying the thickness that determines the contacting surfaces to be
    #: tracked. The input value for this parameter cannot be negative. An internal default
    #: value is used if a zero value is input or if the parameter is omitted.
    trackingThickness: float = None

    #: An Int specifying the number of state-dependent variables. The default value is 0. This
    #: argument is applicable only if **modelType** = MODELTYPE_USER or
    #: **modelType** = MODELTYPE_USER_INTERACTION.
    dependentVariables: int = 0

    #: An Int specifying the number of property values required. The default value is 0. This
    #: argument is applicable only if **modelType** = MODELTYPE_USER or
    #: **modelType** = MODELTYPE_USER_INTERACTION.
    numProperties: int = 0

    #: A Boolean specifying whether to use unsymmetric equation solution procedures. This
    #: argument is applicable only if **modelType** = MODELTYPE_USER or
    #: **modelType** = MODELTYPE_USER_INTERACTION.
    useUnsymmetricEqunProcedure: Boolean = OFF

    #: A SymbolicConstant specifying the surface interaction model type.
    modelType: SymbolicConstant = None

    @abaqus_method_doc
    def __init__(
        self,
        contactArea: float = 1,
        padThickness: float = None,
        trackingThickness: float = None,
        dependentVariables: int = 0,
        numProperties: int = 0,
        useUnsymmetricEqunProcedure: Boolean = OFF,
        modelType: SymbolicConstant = None,
    ):
        """This method creates a GeometricProperties object.

        .. note:: 
            This function can be accessed by:

            .. code-block:: python

                mdb.models[name].interactionProperties[name].GeometricProperties

        Parameters
        ----------
        contactArea
            A Float specifying the out-of-plane thickness of the surface for a two-dimensional model
            or cross-sectional area for every node in the node-based surface. The default value is
            1.0.
        padThickness
            None or a Float specifying the thickness of an interfacial layer between the contacting
            surfaces. If **padThickness** = None, there is no interfacial layer. The default value is
            None.
        trackingThickness
            None or a Float specifying the thickness that determines the contacting surfaces to be
            tracked. The input value for this parameter cannot be negative. An internal default
            value is used if a zero value is input or if the parameter is omitted.
        dependentVariables
            An Int specifying the number of state-dependent variables. The default value is 0. This
            argument is applicable only if **modelType** = MODELTYPE_USER or
            **modelType** = MODELTYPE_USER_INTERACTION.
        numProperties
            An Int specifying the number of property values required. The default value is 0. This
            argument is applicable only if **modelType** = MODELTYPE_USER or
            **modelType** = MODELTYPE_USER_INTERACTION.
        useUnsymmetricEqunProcedure
            A Boolean specifying whether to use unsymmetric equation solution procedures. This
            argument is applicable only if **modelType** = MODELTYPE_USER or
            **modelType** = MODELTYPE_USER_INTERACTION.
        modelType
            A SymbolicConstant specifying the surface interaction model type.

        Returns
        -------
        GeometricProperties
            A :py:class:`~abaqus.Interaction.GeometricProperties.GeometricProperties` object.
        """
        ...

    @abaqus_method_doc
    def setValues(self, *args, **kwargs):
        """This method modifies the GeometricProperties object."""
        ...



import typing

from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc


@abaqus_class_doc
class OptimizationObjective:
    """An OptimizationObjective is an object used to define objectives in an objective
    function.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import optimization
            mdb.models[name].optimizationTasks[name].objectiveFunctions[name].objectives[i]
    """

    #: A Boolean specifying whether the objective is suppressed or not. The default value is
    #: OFF.
    suppress: Boolean = OFF

    #: A Float specifying the weight applied to the design response value. The default value is
    #: 1.0.
    weight: float = 1

    #: The SymbolicConstant DEFAULT or a Float specifying the reference value used in
    #: evaluating a design response. For topology optimization, DEFAULT> indicates the
    #: reference value is 0. For shape optimization, DEFAULT indicates the reference value is
    #: the nodal average. The default value is DEFAULT.
    referenceValue: typing.Union[SymbolicConstant, float] = DEFAULT

    #: A String specifying the name of the design response.
    designResponse: str = ""



from .LoadState import LoadState
from ..UtilityAndView.abaqusConstants import *
from .._decorators import abaqus_class_doc


@abaqus_class_doc
class ConnectorForceState(LoadState):
    """The ConnectorForceState object stores the propagating data for a connector force in a
    step. One instance of this object is created internally by the ConnectorForce object for
    each step. The instance is also deleted internally by the ConnectorForce object.
    The ConnectorForceState object has no constructor or methods.
    The ConnectorForceState object is derived from the LoadState object.

    .. note:: 
        This object can be accessed by:

        .. code-block:: python

            import load
            mdb.models[name].steps[name].loadStates[name]

        The corresponding analysis keywords are:

        - CONNECTOR LOAD
    """

    #: A Float or a Complex specifying the connector force component in the connector's local
    #: 1-direction.
    f1: float = None

    #: A Float or a Complex specifying the connector force component in the connector's local
    #: 2-direction.
    f2: float = None

    #: A Float or a Complex specifying the connector force component in the connector's local
    #: 3-direction.
    f3: float = None

    #: A SymbolicConstant specifying the propagation state of the connector force component in
    #: the connector's local 1-direction. Possible values are UNSET, SET, UNCHANGED, and
    #: MODIFIED.
    f1State: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the connector force component in
    #: the connector's local 2-direction. Possible values are UNSET, SET, UNCHANGED, and
    #: MODIFIED.
    f2State: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the connector force component in
    #: the connector's local 3-direction. Possible values are UNSET, SET, UNCHANGED, and
    #: MODIFIED.
    f3State: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the **amplitude** member. Possible
    #: values are UNSET, SET, UNCHANGED, and FREED.
    amplitudeState: SymbolicConstant = None

    #: A SymbolicConstant specifying the propagation state of the LoadState object. Possible
    #: values are:
    #: 
    #: - NOT_YET_ACTIVE
    #: - CREATED
    #: - PROPAGATED
    #: - MODIFIED
    #: - DEACTIVATED
    #: - NO_LONGER_ACTIVE
    #: - TYPE_NOT_APPLICABLE
    #: - INSTANCE_NOT_APPLICABLE
    #: - BUILT_INTO_BASE_STATE
    status: SymbolicConstant = None

    #: A String specifying the name of the amplitude reference. The String is empty if the load
    #: has no amplitude reference.
    amplitude: str = ""
